@@ -33,6 +33,7 @@ __all__ = (
     "DirectoryDescriptionTypeDef",
     "DirectoryLimitsTypeDef",
     "DirectoryVpcSettingsDescriptionTypeDef",
+    "DirectoryVpcSettingsTypeDef",
     "DomainControllerTypeDef",
     "EventTopicTypeDef",
     "IpRouteInfoTypeDef",
@@ -40,6 +41,8 @@ __all__ = (
     "LogSubscriptionTypeDef",
     "OwnerDirectoryDescriptionTypeDef",
     "RadiusSettingsTypeDef",
+    "RegionDescriptionTypeDef",
+    "RegionsInfoTypeDef",
     "SchemaExtensionInfoTypeDef",
     "SharedDirectoryTypeDef",
     "SnapshotLimitsTypeDef",
@@ -63,11 +66,11 @@ __all__ = (
     "DescribeDomainControllersResultTypeDef",
     "DescribeEventTopicsResultTypeDef",
     "DescribeLDAPSSettingsResultTypeDef",
+    "DescribeRegionsResultTypeDef",
     "DescribeSharedDirectoriesResultTypeDef",
     "DescribeSnapshotsResultTypeDef",
     "DescribeTrustsResultTypeDef",
     "DirectoryConnectSettingsTypeDef",
-    "DirectoryVpcSettingsTypeDef",
     "GetDirectoryLimitsResultTypeDef",
     "GetSnapshotLimitsResultTypeDef",
     "IpRouteTypeDef",
@@ -202,6 +205,7 @@ DirectoryDescriptionTypeDef = TypedDict(
         "SsoEnabled": bool,
         "DesiredNumberOfDomainControllers": int,
         "OwnerDirectoryDescription": "OwnerDirectoryDescriptionTypeDef",
+        "RegionsInfo": "RegionsInfoTypeDef",
     },
     total=False,
 )
@@ -228,6 +232,10 @@ DirectoryVpcSettingsDescriptionTypeDef = TypedDict(
     total=False,
 )
 
+DirectoryVpcSettingsTypeDef = TypedDict(
+    "DirectoryVpcSettingsTypeDef", {"VpcId": str, "SubnetIds": List[str]}
+)
+
 DomainControllerTypeDef = TypedDict(
     "DomainControllerTypeDef",
     {
@@ -318,6 +326,38 @@ RadiusSettingsTypeDef = TypedDict(
     total=False,
 )
 
+RegionDescriptionTypeDef = TypedDict(
+    "RegionDescriptionTypeDef",
+    {
+        "DirectoryId": str,
+        "RegionName": str,
+        "RegionType": Literal["Primary", "Additional"],
+        "Status": Literal[
+            "Requested",
+            "Creating",
+            "Created",
+            "Active",
+            "Inoperable",
+            "Impaired",
+            "Restoring",
+            "RestoreFailed",
+            "Deleting",
+            "Deleted",
+            "Failed",
+        ],
+        "VpcSettings": "DirectoryVpcSettingsTypeDef",
+        "DesiredNumberOfDomainControllers": int,
+        "LaunchTime": datetime,
+        "StatusLastUpdatedDateTime": datetime,
+        "LastUpdatedDateTime": datetime,
+    },
+    total=False,
+)
+
+RegionsInfoTypeDef = TypedDict(
+    "RegionsInfoTypeDef", {"PrimaryRegion": str, "AdditionalRegions": List[str]}, total=False
+)
+
 SchemaExtensionInfoTypeDef = TypedDict(
     "SchemaExtensionInfoTypeDef",
     {
@@ -495,6 +535,12 @@ DescribeLDAPSSettingsResultTypeDef = TypedDict(
     total=False,
 )
 
+DescribeRegionsResultTypeDef = TypedDict(
+    "DescribeRegionsResultTypeDef",
+    {"RegionsDescription": List["RegionDescriptionTypeDef"], "NextToken": str},
+    total=False,
+)
+
 DescribeSharedDirectoriesResultTypeDef = TypedDict(
     "DescribeSharedDirectoriesResultTypeDef",
     {"SharedDirectories": List["SharedDirectoryTypeDef"], "NextToken": str},
@@ -516,10 +562,6 @@ DirectoryConnectSettingsTypeDef = TypedDict(
     {"VpcId": str, "SubnetIds": List[str], "CustomerDnsIps": List[str], "CustomerUserName": str},
 )
 
-DirectoryVpcSettingsTypeDef = TypedDict(
-    "DirectoryVpcSettingsTypeDef", {"VpcId": str, "SubnetIds": List[str]}
-)
-
 GetDirectoryLimitsResultTypeDef = TypedDict(
     "GetDirectoryLimitsResultTypeDef", {"DirectoryLimits": "DirectoryLimitsTypeDef"}, total=False
 )
